define((()=>(()=>{var e={758:(e,r,t)=>{t.p=document.querySelector("body").getAttribute("data-base-url")+"nbextensions/ipywidgetvar",window.require&&window.require.config({map:{"*":{ipywidgetvar:"nbextensions/ipywidgetvar/index"}}}),e.exports={load_ipython_extension:function(){}}}},r={};function t(i){var n=r[i];if(void 0!==n)return n.exports;var o=r[i]={exports:{}};return e[i](o,o.exports,t),o.exports}return t.p="",t(758)})()));